Index: trunk/psModules/src/camera/pmFPAview.h
===================================================================
--- trunk/psModules/src/camera/pmFPAview.h	(revision 7017)
+++ trunk/psModules/src/camera/pmFPAview.h	(revision 7589)
@@ -7,6 +7,6 @@
 *  @author EAM, IfA
 *
-*  @version $Revision: 1.1 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2006-05-01 01:55:43 $
+*  @version $Revision: 1.2 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2006-06-17 01:50:43 $
 *
 *  Copyright 2004-2005 Institute for Astronomy, University of Hawaii
@@ -20,13 +20,4 @@
 /// @addtogroup AstroImage
 /// @{
-
-// depth of interest
-typedef enum {
-    PM_FPA_DEPTH_NONE,
-    PM_FPA_DEPTH_FPA,
-    PM_FPA_DEPTH_CHIP,
-    PM_FPA_DEPTH_CELL,
-    PM_FPA_DEPTH_READOUT,
-} pmFPAdepth;
 
 typedef struct
@@ -43,6 +34,6 @@
 pmFPAview *pmFPAviewAlloc (int nRows);
 
-// determine the current view depth
-pmFPAdepth pmFPAviewDepth (const pmFPAview *view);
+// determine the current view level
+pmFPALevel pmFPAviewLevel (const pmFPAview *view);
 
 // return the currently selected chip for this view
